built_modules = list(name for name in
    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;X11Extras;Xml;XmlPatterns;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLFunctions;Positioning;Location;Qml;Quick;QuickControls2;QuickWidgets;RemoteObjects;Scxml;Script;ScriptTools;Sensors;SerialPort;TextToSpeech;Charts;Svg;DataVisualization;UiTools;WebChannel;WebEngineCore;WebEngine;WebEngineWidgets;WebSockets;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
    .split(";"))

shiboken_library_soversion = str(5.15)
pyside_library_soversion = str(5.15)

version = "5.15.16"
version_info = (5, 15, 16, "", "")

__build_date__ = '2025-07-27T20:28:10+00:00'
__build_commit_date__ = '2025-07-24T19:10:19+00:00'
__build_commit_hash__ = '50c5d7b0badea6b84beb5e5e7210c27b7c36f6a4'



